==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebCore/page/LinkDecorationFilteringData.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/RegistrableDomain.h>

namespace WebCore {

struct LinkDecorationFilteringData {
    RegistrableDomain domain;
    String path;
    String linkDecoration;

    LinkDecorationFilteringData(RegistrableDomain&& domain, String&& path, String&& linkDecoration)
        : domain(WTFMove(domain))
        , path(WTFMove(path))
        , linkDecoration(WTFMove(linkDecoration))
    {
    }

    LinkDecorationFilteringData(String&& domain, String&& path, String&& linkDecoration)
        : LinkDecorationFilteringData(RegistrableDomain { URL { WTFMove(domain) } }, WTFMove(path), WTFMove(linkDecoration))
    {
    }

    LinkDecorationFilteringData(const LinkDecorationFilteringData&) = default;
    LinkDecorationFilteringData& operator=(const LinkDecorationFilteringData&) = default;

    LinkDecorationFilteringData(LinkDecorationFilteringData&& data)
        : domain(WTFMove(data.domain))
        , path(WTFMove(data.path))
        , linkDecoration(WTFMove(data.linkDecoration))
    {
    }

    LinkDecorationFilteringData& operator=(LinkDecorationFilteringData&& data)
    {
        domain = WTFMove(data.domain);
        path = WTFMove(data.path);
        linkDecoration = WTFMove(data.linkDecoration);
        return *this;
    }
};

}

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebCore/page/LinkDecorationFilteringData.h <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/RegistrableDomain.h>

namespace WebCore {

struct LinkDecorationFilteringData {
    RegistrableDomain domain;
    String path;
    String linkDecoration;

    LinkDecorationFilteringData(RegistrableDomain&& domain, String&& path, String&& linkDecoration)
        : domain(WTF::move(domain))
        , path(WTF::move(path))
        , linkDecoration(WTF::move(linkDecoration))
    {
    }

    LinkDecorationFilteringData(String&& domain, String&& path, String&& linkDecoration)
        : LinkDecorationFilteringData(RegistrableDomain { URL { WTF::move(domain) } }, WTF::move(path), WTF::move(linkDecoration))
    {
    }

    LinkDecorationFilteringData(const LinkDecorationFilteringData&) = default;
    LinkDecorationFilteringData& operator=(const LinkDecorationFilteringData&) = default;

    LinkDecorationFilteringData(LinkDecorationFilteringData&& data)
        : domain(WTF::move(data.domain))
        , path(WTF::move(data.path))
        , linkDecoration(WTF::move(data.linkDecoration))
    {
    }

    LinkDecorationFilteringData& operator=(LinkDecorationFilteringData&& data)
    {
        domain = WTF::move(data.domain);
        path = WTF::move(data.path);
        linkDecoration = WTF::move(data.linkDecoration);
        return *this;
    }
};

}
